==> server-api-impl-10.3.0-907.1102-sources.jar: com/xebialabs/deployit/core/rest/json/ConfigurationItemIdsJsonWriter.java <==
package com.xebialabs.deployit.core.rest.json;

import com.google.common.annotations.VisibleForTesting;
import com.xebialabs.deployit.engine.api.dto.ConfigurationItemId;
import com.xebialabs.xltype.serialization.json.JsonWriter;
import org.springframework.stereotype.Component;

import javax.ws.rs.Consumes;
import javax.ws.rs.Produces;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyWriter;
import javax.ws.rs.ext.Provider;
import java.io.IOException;
import java.io.OutputStream;
import java.io.StringWriter;
import java.lang.annotation.Annotation;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.Collection;

@Component
@Provider
@Consumes({MediaType.APPLICATION_JSON})
@Produces({MediaType.APPLICATION_JSON})
public class ConfigurationItemIdsJsonWriter implements MessageBodyWriter<Collection<ConfigurationItemId>> {

    @Override
    public boolean isWriteable(Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType) {
        if (Collection.class.isAssignableFrom(type) && genericType instanceof ParameterizedType) {
            type = (Class<?>) ((ParameterizedType) genericType).getActualTypeArguments()[0];
        }
        return ConfigurationItemId.class.isAssignableFrom(type);
    }

    @Override
    public long getSize(final Collection<ConfigurationItemId> configurationItemId, final Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType) {
        return -1L;
    }

    @Override
    public void writeTo(final Collection<ConfigurationItemId> configurationItemId, final Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType, final MultivaluedMap<String, Object> httpHeaders, final OutputStream entityStream) throws IOException, WebApplicationException {
        entityStream.write(toJson(configurationItemId).getBytes());
    }

    @VisibleForTesting
    String toJson(Collection<ConfigurationItemId> configurationItemIds) {
        StringWriter stringWriter = new StringWriter();
        JsonWriter writer = new JsonWriter(stringWriter);
        writer.array();

        for (ConfigurationItemId configurationItemId : configurationItemIds) {
            new ConfigurationItemIdJsonWriter().writeJson(configurationItemId, writer);
        }

        writer.endArray();
        return stringWriter.toString();
    }
}

==> server-api-impl-10.4.0-1111.1103-sources.jar: com/xebialabs/deployit/core/rest/json/ConfigurationItemIdsJsonWriter.java <==
package com.xebialabs.deployit.core.rest.json;

import com.google.common.annotations.VisibleForTesting;
import com.xebialabs.deployit.engine.api.dto.ConfigurationItemId;
import com.xebialabs.xltype.serialization.json.JsonWriter;
import org.springframework.stereotype.Component;

import javax.ws.rs.Consumes;
import javax.ws.rs.Produces;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyWriter;
import javax.ws.rs.ext.Provider;
import java.io.IOException;
import java.io.OutputStream;
import java.io.StringWriter;
import java.lang.annotation.Annotation;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.Collection;

@Component
@Provider
@Consumes({MediaType.APPLICATION_JSON})
@Produces({MediaType.APPLICATION_JSON})
public class ConfigurationItemIdsJsonWriter implements MessageBodyWriter<Collection<? extends ConfigurationItemId>> {

    @Override
    public boolean isWriteable(Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType) {
        if (Collection.class.isAssignableFrom(type) && genericType instanceof ParameterizedType) {
            type = (Class<?>) ((ParameterizedType) genericType).getActualTypeArguments()[0];
        }
        return ConfigurationItemId.class.isAssignableFrom(type);
    }

    @Override
    public long getSize(final Collection<? extends ConfigurationItemId> configurationItemId, final Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType) {
        return -1L;
    }

    @Override
    public void writeTo(final Collection<? extends ConfigurationItemId> configurationItemId, final Class<?> type, final Type genericType, final Annotation[] annotations, final MediaType mediaType, final MultivaluedMap<String, Object> httpHeaders, final OutputStream entityStream) throws IOException, WebApplicationException {
        entityStream.write(toJson(configurationItemId).getBytes());
    }

    @VisibleForTesting
    String toJson(Collection<? extends ConfigurationItemId> configurationItemIds) {
        StringWriter stringWriter = new StringWriter();
        JsonWriter writer = new JsonWriter(stringWriter);
        writer.array();

        for (ConfigurationItemId configurationItemId : configurationItemIds) {
            new ConfigurationItemIdJsonWriter().writeJson(configurationItemId, writer);
        }

        writer.endArray();
        return stringWriter.toString();
    }
}
